==> spip_4.0.4.orig.tar.xz: plugins-dist/revisions/lang/revisions_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=fr_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Voir les différences',

	// D
	'diff_para_ajoute' => 'Paragraphe ajouté',
	'diff_para_deplace' => 'Paragraphe déplacé',
	'diff_para_supprime' => 'Paragraphe supprimé',
	'diff_texte_ajoute' => 'Texte ajouté',
	'diff_texte_deplace' => 'Texte déplacé',
	'diff_texte_supprime' => 'Texte supprimé',
	'differences_versions' => 'Différences entre version N<sup>o</sup>@id_version@ et version N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurer la version N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Suivi des révisions',
	'info_1_revision' => '1 révision',
	'info_aucune_revision' => 'Aucune révision',
	'info_historique' => 'Révisions :',
	'info_historique_lien' => 'Afficher l’historique des modifications',
	'info_historique_titre' => 'Suivi des révisions',
	'info_nb_revisions' => '@nb@ révisions',

	// L
	'label_choisir_id_version' => 'Sélectionnez les versions à comparer',
	'label_config_revisions_objets' => 'Sur quels objets activer les révisions :',

	// M
	'message_valider_recuperer_version' => 'Validez le formulaire pour revenir à cette version.',

	// O
	'objet_editorial' => 'objet',

	// P
	'plugin_update' => 'Mise à jour du plugin "Révisions" en version @version@.',

	// T
	'titre_form_revisions_objets' => 'Activer les révisions',
	'titre_restaurer_version' => 'Restaurer une version',
	'titre_revisions' => 'Révisions',

	// V
	'version_deplace_rubrique' => 'Déplacé de <b>« @from@ »</b> vers <b>« @to@ »</b>.',
	'version_initiale' => 'Version initiale',
	'voir_differences' => 'Voir les différences',
	'voir_mes_revisions' => 'Mes révisions',
	'voir_revisions' => 'Voir les révisions (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Toutes les révisions'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=fr_fem
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Voir les différences',

	// D
	'diff_para_ajoute' => 'Paragraphe ajouté',
	'diff_para_deplace' => 'Paragraphe déplacé',
	'diff_para_supprime' => 'Paragraphe supprimé',
	'diff_texte_ajoute' => 'Texte ajouté',
	'diff_texte_deplace' => 'Texte déplacé',
	'diff_texte_supprime' => 'Texte supprimé',
	'differences_versions' => 'Différences entre version N<sup>o</sup>@id_version@ et version N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Restaurer la version N<sup>o</sup>@version@',
	'icone_suivi_revisions' => 'Suivi des révisions',
	'info_1_revision' => '1 révision',
	'info_aucune_revision' => 'Aucune révision',
	'info_historique' => 'Révisions :',
	'info_historique_lien' => 'Afficher l’historique des modifications',
	'info_historique_titre' => 'Suivi des révisions',
	'info_nb_revisions' => '@nb@ révisions',

	// L
	'label_choisir_id_version' => 'Sélectionnez les versions à comparer',
	'label_config_revisions_objets' => 'Sur quels objets activer les révisions :',

	// M
	'message_valider_recuperer_version' => 'Validez le formulaire pour revenir à cette version.',

	// O
	'objet_editorial' => 'objet',

	// P
	'plugin_update' => 'Mise à jour du plugin "Révisions" en version @version@.',

	// T
	'titre_form_revisions_objets' => 'Activer les révisions',
	'titre_restaurer_version' => 'Restaurer une version',
	'titre_revisions' => 'Révisions',

	// V
	'version_deplace_rubrique' => 'Déplacé de <b>« @from@ »</b> vers <b>« @to@ »</b>.',
	'version_initiale' => 'Version initiale',
	'voir_differences' => 'Voir les différences',
	'voir_mes_revisions' => 'Mes révisions',
	'voir_revisions' => 'Voir les révisions (@objet@ @id_objet@ : @titre@)',
	'voir_toutes_les_revisions' => 'Toutes les révisions',
];
